@@ -1,8 +1,10 @@
+mod add_block_extension_cf;
 mod add_extra_data_hash;
 mod add_number_hash_mapping;
 mod cell;
 mod table_to_struct;
 
+pub use add_block_extension_cf::AddBlockExtensionColumnFamily;
 pub use add_extra_data_hash::AddExtraDataHash;
 pub use add_number_hash_mapping::AddNumberHashMapping;
 pub use cell::CellMigration;
